<?xml version="1.0" ?><!DOCTYPE TS><TS language="bg" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin Преглед на изображения</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Версия:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>изображение</translation>
    </message>
    <message>
        <source>images</source>
        <translation>изображения</translation>
    </message>
    <message>
        <source>album</source>
        <translation>албум</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>албуми</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Управление на синхронизацията</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Синхронизиране:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Нов албум</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Без име</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Наскоро внесени</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Моите любими</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Сигурен ли сте, че искате да изтриете този албум?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Изтриване</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Моите любими</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Хронология</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавяне</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Може да добавите папка за синхронизиране или да изтеглите изображения към хронологията</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Без име</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Изглед</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Слайд шоу</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Преименуване</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копиране</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Изтриване</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin Преглед на изображение</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>изображения</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Сигурен ли сте, че искате да добавите снимки в албума?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Синхронизирай и Създай</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Синхронизиране</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Сигурен ли сте, че искате да добавите списък за синхронизиране и да създадете албум с името на тази папка?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Успешен експорт</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Неуспешен експорт</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Запазване</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Сигурен ли сте, че искате да изпратите снимките в кошчето?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отказ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Изтриване</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Информация за изображението</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Този файл има множество страници, моля използвайте Evince, за да ги видите.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Изглед</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Цял екран</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Слайд шоу</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Печат</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копиране</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Копиране в системния буфер</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Премахване от албума</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Любими</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Премахване от Любими</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Завъртане по часовниковата стрелка</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Завъртане обратно на часовниковата стрелка</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Задаване, като тапет</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Показване във файловия мениджър</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Информация за изображението</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавяне</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Вие може да добавите папка за синхронизиране или да изтегляте и пускате изображение на стената</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Добавяне а албума</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Добави в нов албум</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Премахване</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Отваряне на Папка</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Нямате права за преглед на това изображение</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Date photoed</source>
        <translation>Дата за заснемане</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Дата на промяна</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Размери</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Размер на файла</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Оцветяване</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Режим на експониране</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Програма за експониране</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Време на експониране</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Светкавица</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Апертура</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Фокусно разстояние</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Максимална апертура</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Режим на измерване</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Баланс на бялото</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Корекция на светкавицата</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Тип на фотоапарата</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Модел на обектива</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Без мащабиране</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Оразмери страницата по картината</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Оразмери картината по страницата</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Мащабирай по:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Милиметри</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Сантиметри</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Инчове</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Позиция на картината</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Мащабиране</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Настройки на картината</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Настройки на картината</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Бленди</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Превключвател</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Плъзгане</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Пръстен</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Избор на Папка</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Тази папка е забранена за синхронизация</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Добавяне на папка</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Управление на синхронизацията на папка</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Списъка с папки е празен</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Отказ от синхронизация</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Изображения</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Устройството е премахнато</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Папката не съществува</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Изчисляване...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Преглед на изображение</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Албум</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Преглед</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Цял екран</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Слайд шоу</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Край на прожекцията</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копиране</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Премахване от албума</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Любими</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Премахване от Любими</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Завъртане по часовниковата стрелка</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Завъртане обратно на часовниковата стрелка</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Задай, като тапет</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Показване във файлов менидджър</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Информация за изображението</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Предишно</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Следващ</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Предишен екран</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Следващ екран</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Нов албум</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Преименуване</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Помощ</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Изход</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Покажи клавишните комбинации</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Премахване</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Моля, въведете нова клавишна комбинация</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Клавишни комбинации</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Преглед на изображение</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Албум</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Възстанови първоначалните настройки</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Преглед</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Цял екран</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Прожекция</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Край</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Печат</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копиране</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Премахване от албума</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Любими</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Премахване от Любими</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Завъртане по часовниковата стрелка</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Завъртане обратно на часовниковата стрелка</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Задаване като тапет</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Показване във файловия мениджър</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Информация за изображението</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Нов албум</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Преименуване</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Изтриване</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Край</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Пауза/Изпълнение</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Настройки на прожекцията</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Ефект за смяна</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Времетраене</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Промяна на времетраенето</translation>
    </message>
    <message>
        <source>second</source>
        <translation>секунда</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Обратно</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Управление на картина</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Моите любими</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>размер 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Оразмеряване според прозореца</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Завъртане обратно на часовниковата стрелка</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Завъртане по часовниковата стрелка</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Премахване от Любими</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Любими</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Премахване</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Няма намерени изображения</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Отваряне на изображение</translation>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 изображение</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 изображения</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Управление на синхронизацията</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Синхронизиране:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Албум</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Добавяне</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Може да добавите папка за синхронизиране или да влачите картинки към хронологията</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Добавяне на албум</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Добави към нов албум</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Изглед</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Цял екран</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Прожекция</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Печат</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копиране</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Копиране в системния буфер</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Любими</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Премахване от Любими</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Завъртане по часовниковата стрелка</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Завъртане обратно на часовниковата стрелка</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Задаване като тапет</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Показване във файлов мениджър</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Информация за изображението</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Премахване</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Настройки за плъзгане</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Ефект</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Времетраене</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Клавишни комбинации</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Изглед</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Албум</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>дд ММММ гггг</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Моите любими</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Наскоро внесени</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Нов албум</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>Deepin Преглед на изображения е модерен и приятен мениджър на изображения.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Той е с възможности за управление, преглед и основни функции за редактиране на изображения.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Тъмна тема</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Deepin преглед на изображения е инструмент за преглед на изображения с моден интерфейс и гладко изпълнение.</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Хронология</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Добавяне към албум</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Добави към нов албум</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Изход от цял екран</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Цял екран</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Прожекция</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Печат</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копиране</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Копиране в системния буфер</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Премахване от албума</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Любими</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Премахване от Любими</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Покажи прозореца за управление</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Скрий прозореца за управление</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Завъртане по часовниковата стрелка</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Завъртане обратно на часовниковата стрелка</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Задаване като тапет</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Показване във файлов мениджър</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Информация за изображението</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Премахване</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Отваряне на изображение</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Всички изображения</translation>
    </message>
</context>
</TS>